"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const react_1 = __importDefault(require("react"));
const react_native_1 = require("react-native");
const theme_1 = require("../Styles/theme");
const ModalHost = props => {
    const { title, content, confirmColor, cancelColor, align = 'left', cancelText = '取消', confirmText = '确定', showCancel = true, mask = true, maskClosable = false, visible, animationType = 'fade', onClose = () => 1, onConfirm = () => 1, } = props;
    return (react_1.default.createElement(react_native_1.Modal, { statusBarTranslucent: true, transparent: true, visible: visible, animationType: animationType, onRequestClose: onClose },
        react_1.default.createElement(react_native_1.Pressable, { style: [styles.container, mask ? styles.mask : undefined], onPress: () => maskClosable && onClose() },
            react_1.default.createElement(react_native_1.Pressable, { style: styles.main, onPress: e => e.stopPropagation() },
                !!title && (react_1.default.createElement(react_native_1.View, { style: styles.title },
                    react_1.default.createElement(react_native_1.Text, { style: styles.titleText }, title))),
                react_1.default.createElement(react_native_1.View, { style: styles.content },
                    react_1.default.createElement(react_native_1.Text, { style: [styles.contentText, { textAlign: align }] }, content)),
                react_1.default.createElement(react_native_1.View, { style: styles.operation },
                    showCancel && (react_1.default.createElement(react_native_1.TouchableHighlight, { underlayColor: "#ddd", style: styles.button, onPress: onClose },
                        react_1.default.createElement(react_native_1.Text, { style: [styles.cancelText, cancelColor ? { color: cancelColor } : undefined] }, cancelText))),
                    react_1.default.createElement(react_native_1.TouchableHighlight, { underlayColor: "#ddd", style: [styles.button, showCancel && styles.buttonBorder], onPress: onConfirm },
                        react_1.default.createElement(react_native_1.Text, { style: [styles.confirmText, confirmColor ? { color: confirmColor } : undefined] }, confirmText)))))));
};
const styles = react_native_1.StyleSheet.create({
    container: {
        width: '100%',
        height: '100%',
        alignItems: 'center',
        justifyContent: 'center',
    },
    mask: {
        backgroundColor: theme_1.Theme.fillMask,
    },
    main: {
        width: '80%',
        backgroundColor: theme_1.Theme.fillBase,
        borderRadius: theme_1.Theme.radiusMd,
    },
    title: {
        marginTop: theme_1.Theme.vSpacingLg,
    },
    titleText: {
        textAlign: 'center',
        color: theme_1.Theme.colorTextBase,
        fontSize: theme_1.Theme.modalFontSizeHeading,
    },
    content: {
        padding: theme_1.Theme.hSpacingLg,
    },
    contentText: {
        fontSize: theme_1.Theme.fontSizeBase,
        color: theme_1.Theme.colorTextParagraph,
    },
    operation: {
        display: 'flex',
        flexDirection: 'row',
        borderTopColor: theme_1.Theme.borderColorBase,
        borderTopWidth: theme_1.Theme.borderWidthSm,
    },
    button: {
        flex: 1,
        justifyContent: 'center',
        alignItems: 'center',
        height: theme_1.Theme.modalButtonHeight,
        lineHeight: theme_1.Theme.modalButtonHeight,
    },
    buttonBorder: {
        borderLeftColor: theme_1.Theme.borderColorBase,
        borderLeftWidth: theme_1.Theme.borderWidthSm,
    },
    cancelText: {
        fontSize: theme_1.Theme.modalButtonFontSize,
        color: theme_1.Theme.colorTextSecondary,
    },
    confirmText: {
        fontSize: theme_1.Theme.modalButtonFontSize,
        color: theme_1.Theme.colorLink,
    },
});
exports.default = ModalHost;
