import React from 'react';
import { StyleSheet, Modal, View, Text, TouchableHighlight } from 'react-native';
import { Theme } from '../Styles/theme';
const ActionSheet = props => {
    const { visible, cancelText = '取消', actions, onClose, onClickItem } = props;
    return (React.createElement(Modal, { visible: visible, transparent: true, animationType: "slide", statusBarTranslucent: true, onRequestClose: onClose },
        React.createElement(View, { style: styles.container },
            React.createElement(View, { style: styles.top }),
            React.createElement(View, { style: styles.sheet },
                actions.map((item, index) => {
                    const { name, subName, color, fontSize, disabled } = item;
                    const style = {};
                    color && (style.color = color);
                    fontSize && (style.fontSize = fontSize);
                    return (React.createElement(TouchableHighlight, { key: index, activeOpacity: 0.6, underlayColor: Theme.fillBody, onPress: () => onClickItem(index), disabled: disabled, style: [styles.sheetItem, index === 0 && styles.noBorder] },
                        React.createElement(React.Fragment, null,
                            React.createElement(View, null,
                                React.createElement(Text, { style: [styles.sheetText, style, disabled && styles.disabledText] }, name)),
                            !!subName && (React.createElement(View, { style: styles.sub },
                                React.createElement(Text, { style: styles.subText }, subName))))));
                }),
                React.createElement(TouchableHighlight, { activeOpacity: 0.6, underlayColor: Theme.fillBody, onPress: onClose, style: [styles.sheetItem, styles.noBorder, styles.cancel] },
                    React.createElement(Text, { style: styles.sheetText }, cancelText))))));
};
const styles = StyleSheet.create({
    container: {
        flex: 1,
        backgroundColor: Theme.fillMask,
    },
    top: {
        flex: 1,
    },
    sheet: {
        backgroundColor: Theme.fillBody,
        borderTopLeftRadius: 10,
        borderTopRightRadius: 10,
        overflow: 'hidden',
    },
    sheetItem: {
        backgroundColor: Theme.fillBase,
        paddingVertical: 15,
        justifyContent: 'center',
        alignItems: 'center',
        borderTopColor: Theme.borderColor,
        borderTopWidth: 0.5,
    },
    noBorder: {
        borderTopWidth: 0,
    },
    sheetText: {
        fontSize: 15,
        color: Theme.colorTextBase,
    },
    disabledText: {
        color: Theme.colorTextDisabled,
    },
    sub: {
        marginTop: 4,
    },
    subText: {
        fontSize: 12,
        color: Theme.colorTextSecondary,
    },
    cancel: {
        marginTop: 8,
    },
});
export default ActionSheet;
