import React, { useRef, useState, useEffect, useMemo } from 'react';
import { StyleSheet, View, ScrollView } from 'react-native';
import CellGroup from '../Cell/cellGroup';
const List = (props) => {
    const { indexList, dataList, renderItem, activeStickyIndex, onKeyIndexChange } = props;
    const [stickyIndex, setStickyIndex] = useState(-1);
    const $scroll = useRef(null);
    // 记录每个标头的index位置
    const keyIndexMap = useRef([]);
    // 记录每一项的高度
    const layoutMap = useRef([]);
    // 延迟渲染的定时器
    const timer = useRef(null);
    // 是否是外部滑动导致的滚动
    const isTouchingByAnchor = useRef(false);
    // 清除定时器
    useEffect(() => {
        return () => {
            timer.current && clearTimeout(timer.current);
        };
    }, []);
    // 外部标头变化导致滚动
    useEffect(() => {
        if (activeStickyIndex >= 0) {
            isTouchingByAnchor.current = true;
            setActiveGroupByIndex(activeStickyIndex);
        }
    }, [activeStickyIndex]);
    const handleDataList = (data) => {
        let res = [];
        let index = 0;
        data.forEach((item, idx) => {
            // 要注意不要赋值，否则会导致引用错误
            keyIndexMap.current.push({ index, offset: 0 });
            const name = indexList[idx];
            res.push({ type: 'anchor', name });
            item.forEach(i => {
                res.push({ type: 'item', data: i });
                index++;
            });
            index++;
        });
        return res;
    };
    const setActiveGroupByIndex = (index) => {
        const currentKeyMap = keyIndexMap.current[index];
        if (currentKeyMap && currentKeyMap.index !== undefined) {
            $scroll?.current?.scrollTo({
                y: currentKeyMap.offset,
                animated: false,
            });
            // 延迟设置stickyHeader，减少渲染，防止卡顿
            if (timer.current) {
                clearTimeout(timer.current);
            }
            timer.current = setTimeout(() => {
                isTouchingByAnchor.current = false;
                setStickyIndex(currentKeyMap.index);
            }, 300);
        }
    };
    const onItemLayout = (event, index, isLast) => {
        layoutMap.current[index] = { height: event.nativeEvent.layout.height };
        if (isLast) {
            const indexMap = keyIndexMap.current;
            const layout = layoutMap.current;
            indexMap.forEach((item, idx) => {
                const prev = idx === 0 ? undefined : indexMap[idx - 1];
                const start = prev ? prev.index : 0;
                let offset = prev ? prev.offset : 0;
                for (let i = start; i < item.index; i++) {
                    const each = layout[i];
                    offset += each.height;
                }
                keyIndexMap.current[idx] = {
                    ...item,
                    offset,
                };
            });
        }
    };
    const onScroll = (event) => {
        if (isTouchingByAnchor.current) {
            return false;
        }
        const { y } = event.nativeEvent.contentOffset;
        const indexMap = keyIndexMap.current;
        let stickyIndex = -1;
        let keyIndex = -1;
        for (let i = 0; i < indexMap.length; i++) {
            const item = indexMap[i];
            const { offset, index } = item;
            if (offset <= y) {
                stickyIndex = index;
                keyIndex = i;
            }
            else {
                break;
            }
        }
        if (stickyIndex !== -1) {
            setStickyIndex(stickyIndex);
            onKeyIndexChange(keyIndex);
        }
    };
    const finalDataList = handleDataList(dataList);
    const listLength = finalDataList.length;
    return useMemo(() => {
        return (React.createElement(ScrollView, { ref: $scroll, style: styles.content, removeClippedSubviews: false, scrollEventThrottle: 8, stickyHeaderIndices: [stickyIndex], onScroll: onScroll }, finalDataList.map((item, index) => {
            return (React.createElement(View, { key: index, onLayout: event => onItemLayout(event, index, index === listLength - 1) }, item.type && item.type === 'anchor' ? (React.createElement(CellGroup, { key: index, title: item.name })) : (renderItem(item.data, index))));
        })));
    }, [dataList, stickyIndex]);
};
const styles = StyleSheet.create({
    content: {
        flex: 1,
    },
});
export default List;
